==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_lo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>ເປີດວາຍຟາຍ</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>ປິດວາຍຟາຍ</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>ຕົວໃຫຍ່</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>ຕົວເລັກ</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>ເປີດແປ້ງເລຂ</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>ປິດແປ້ງເລຂ</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>ເປີດແປ້ງສັມ಑ພັດ</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>ປິດແປ້ງສັມ಑ພັດ</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>ສລັບແປ້ງສັມ಑ພັດ</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>ສລັບ Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>ເປີດໂໝດເຄື່ອງບິນ</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>ປິດໂໝດເຄື່ອງບິນ</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>ໂໝດດຸນນະພາບ</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>ໂໝດປະຍັດໄຟ</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>ໂໝດປະສິດທິພາບສູງ</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>ເປີດພາບກິດຈະກໍາຫນ້າຕ່າງ</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>ປິດພາບກິດຈະກໍາຫນ້າຕ່າງ</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>ເປີດພາບກິດຈະກໍາຫນ້າຕ່າງບໍ່ສໍາເລັດ</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>ປິດໄມໂຄຣໂຟນ</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>ເປີດໄມໂຄຣໂຟນ</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_lo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lo">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>ເປີດວາຍຟາຍ</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>ປິດວາຍຟາຍ</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>ຕົວໃຫຍ່</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>ຕົວເລັກ</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>ເປີດແປ້ງເລຂ</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>ປິດແປ້ງເລຂ</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>ເປີດແປ້ງສັມ಑ພັດ</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>ປິດແປ້ງສັມ಑ພັດ</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>ສລັບແປ້ງສັມ಑ພັດ</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>ສລັບ Fn</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>ເປີດໂໝດເຄື່ອງບິນ</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>ປິດໂໝດເຄື່ອງບິນ</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>ໂໝດດຸນນະພາບ</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>ໂໝດປະຍັດໄຟ</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>ໂໝດປະສິດທິພາບສູງ</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>ເປີດພາບກິດຈະກໍາຫນ້າຕ່າງ</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>ປິດພາບກິດຈະກໍາຫນ້າຕ່າງ</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>ເປີດພາບກິດຈະກໍາຫນ້າຕ່າງບໍ່ສໍາເລັດ</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>ປິດໄມໂຄຣໂຟນ</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>ເປີດໄມໂຄຣໂຟນ</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera off</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
